@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,6 +51,11 @@ package com.openexchange.templating;
 
 import java.io.IOException;
 import java.io.Writer;
+
+import com.openexchange.templating.base.OXTemplate;
+import com.openexchange.templating.base.TemplateException;
+
+import freemarker.template.Configuration;
 import freemarker.template.Template;
 
 /**
@@ -59,7 +64,8 @@ import freemarker.template.Template;
 public class OXTemplateImpl implements OXTemplate{
 
     private Template template;
-
+    private TemplateLevel level = TemplateLevel.USER;
+   
     public Template getTemplate() {
         return template;
     }
@@ -78,4 +84,12 @@ public class OXTemplateImpl implements OXTemplate{
         }
     }
 
+    public TemplateLevel getLevel() {
+        return level;
+    }
+    
+    public void setLevel(TemplateLevel level) {
+        this.level = level;
+    }
+
 }
