@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,9 +49,10 @@
 
 package com.openexchange.templating.impl;
 
+import java.util.List;
 import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.container.FolderObject;
-import com.openexchange.tools.session.ServerSession;
+import com.openexchange.session.Session;
 
 
 /**
@@ -61,6 +62,7 @@ import com.openexchange.tools.session.ServerSession;
  *
  */
 public interface OXInfostoreHelper {
-    public String findTemplateInFolder(ServerSession session, FolderObject folder, String name) throws AbstractOXException;
-    public void storeTemplateInFolder(ServerSession session, FolderObject folder, String name, String templateText) throws AbstractOXException;
+    public String findTemplateInFolder(Session session, FolderObject folder, String name) throws AbstractOXException;
+    public void storeTemplateInFolder(Session session, FolderObject folder, String name, String templateText) throws AbstractOXException;
+    public List<String> getNames(Session session, FolderObject folder, String... filter) throws AbstractOXException;
 }
