@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -56,7 +56,12 @@ import java.io.InputStream;
 import java.io.InputStreamReader;
 import java.io.UnsupportedEncodingException;
 import java.sql.SQLException;
+import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.HashSet;
+import java.util.List;
+import java.util.Set;
+
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import com.openexchange.groupware.AbstractOXException;
@@ -67,11 +72,13 @@ import com.openexchange.groupware.infostore.InfostoreFacade;
 import com.openexchange.groupware.infostore.database.impl.DocumentMetadataImpl;
 import com.openexchange.groupware.infostore.utils.Metadata;
 import com.openexchange.server.impl.OCLPermission;
+import com.openexchange.session.Session;
 import com.openexchange.templating.TemplateErrorMessage;
 import com.openexchange.tools.iterator.SearchIterator;
 import com.openexchange.tools.oxfolder.OXFolderAccess;
 import com.openexchange.tools.oxfolder.OXFolderManager;
 import com.openexchange.tools.session.ServerSession;
+import com.openexchange.tools.session.ServerSessionAdapter;
 
 
 /**
@@ -82,7 +89,7 @@ import com.openexchange.tools.session.ServerSession;
  */
 public class OXIntegration implements OXFolderHelper, OXInfostoreHelper {
 
-    private static final Log LOG = LogFactory.getLog(OXIntegration.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(OXIntegration.class));
 
     private static final String TEMPLATE_FOLDER_NAME = "OXMF Templates";
     
@@ -92,9 +99,9 @@ public class OXIntegration implements OXFolderHelper, OXInfostoreHelper {
         this.infostore = infostore;
     }
     
-    public FolderObject createPrivateTemplateFolder(ServerSession session) throws AbstractOXException {
+    public FolderObject createPrivateTemplateFolder(Session session) throws AbstractOXException {
         OXFolderManager manager = OXFolderManager.getInstance(session);
-        OXFolderAccess access = getFolderAccess(session);
+        OXFolderAccess access = getFolderAccess(ServerSessionAdapter.valueOf(session));
         
         FolderObject parent = access.getDefaultFolder(session.getUserId(), FolderObject.INFOSTORE);
         
@@ -115,11 +122,13 @@ public class OXIntegration implements OXFolderHelper, OXInfostoreHelper {
         return manager.createFolder(fo, true, System.currentTimeMillis());
     }
 
-    public FolderObject getGlobalTemplateFolder(ServerSession session) throws AbstractOXException {
+    public FolderObject getGlobalTemplateFolder(Session baseSession) throws AbstractOXException {
+    	ServerSession session = ServerSessionAdapter.valueOf(baseSession);
         return findTemplatesSubfolder(FolderObject.SYSTEM_PUBLIC_INFOSTORE_FOLDER_ID, getFolderAccess(session), session.getContext());
     }
 
-    public FolderObject getPrivateTemplateFolder(ServerSession session) throws AbstractOXException {
+    public FolderObject getPrivateTemplateFolder(Session baseSession) throws AbstractOXException {
+    	ServerSession session = ServerSessionAdapter.valueOf(baseSession);
         OXFolderAccess access = getFolderAccess(session);
         FolderObject privateInfostoreFolder = access.getDefaultFolder(session.getUserId(), FolderObject.INFOSTORE);
         return findTemplatesSubfolder(privateInfostoreFolder, access, session.getContext());
@@ -148,7 +157,8 @@ public class OXIntegration implements OXFolderHelper, OXInfostoreHelper {
         return null;
     }
 
-    public String findTemplateInFolder(ServerSession session, FolderObject folder, String name) throws AbstractOXException {
+    public String findTemplateInFolder(Session baseSession, FolderObject folder, String name) throws AbstractOXException {
+    	ServerSession session = ServerSessionAdapter.valueOf(baseSession);
         SearchIterator<DocumentMetadata> iterator = infostore.getDocuments(folder.getObjectID(), new Metadata[]{Metadata.ID_LITERAL, Metadata.TITLE_LITERAL, Metadata.FILENAME_LITERAL}, session.getContext(), session.getUser(), session.getUserConfiguration()).results();
         BufferedReader reader = null;
         try {
@@ -190,7 +200,7 @@ public class OXIntegration implements OXFolderHelper, OXInfostoreHelper {
         return null;
     }
 
-    public void storeTemplateInFolder(ServerSession session, FolderObject folder, String name, String templateText) throws AbstractOXException {
+    public void storeTemplateInFolder(Session session, FolderObject folder, String name, String templateText) throws AbstractOXException {
         DocumentMetadata metadata = new DocumentMetadataImpl();
         metadata.setFileName(name);
         metadata.setTitle(name);
@@ -199,10 +209,31 @@ public class OXIntegration implements OXFolderHelper, OXInfostoreHelper {
         metadata.setFileMIMEType("text/plain");
         
         try {
-            infostore.saveDocument(metadata, new ByteArrayInputStream(templateText.getBytes("UTF-8")), InfostoreFacade.NEW, session);
+            infostore.saveDocument(metadata, new ByteArrayInputStream(templateText.getBytes("UTF-8")), InfostoreFacade.NEW, ServerSessionAdapter.valueOf(session));
         } catch (UnsupportedEncodingException e) {
             LOG.fatal(e.getMessage(), e);
         }
     }
 
+    public List<String> getNames(Session baseSession, FolderObject folder, String ... filter) throws AbstractOXException {
+    	ServerSession session = ServerSessionAdapter.valueOf(baseSession);
+    	HashSet<String> sieve = new HashSet<String>(Arrays.asList(filter));
+    	
+        SearchIterator<DocumentMetadata> iterator = infostore.getDocuments(folder.getObjectID(), new Metadata[]{Metadata.FILENAME_LITERAL, Metadata.CATEGORIES_LITERAL}, session.getContext(), session.getUser(), session.getUserConfiguration()).results();
+        List<String> names = new ArrayList<String>(30);
+        while(iterator.hasNext()) {
+            DocumentMetadata doc = iterator.next();
+            Set<String> categories = null;
+            
+            if(doc.getCategories() != null && doc.getCategories().length() > 0){
+                categories = new HashSet<String>(Arrays.asList(doc.getCategories().split("\\s*,\\s*")));
+            }
+            	
+			if(categories == null || categories.containsAll(sieve)) {
+				names.add(doc.getFileName());				
+			}
+        }
+        return names;
+    }
+
 }
